Credits
=======

Thanks goes to all the kind PyInstaller contributors who have contributed
new code, bug reports, fixes, comments and ideas. A brief list follows,
please let us know if your name is omitted by accident:


Contributions to PyInstaller 3.4
----------------------------------

* Hartmut Goebel - Core developer, maintainer and release manager.
* Bryan A. Jones - Core developer and PyQt5-tamer.
* David Vierra - Core developer and encoding specialist.
* xoviat - brave contributor
* Hugo vk - brave contributor

* Mickaël Schoentgen, Charles Nicholson, Jonathan Springer, Benoît
  Vinot, Brett Higgins, Dustin Spicuzza, Marco Nenciarini, Aaron
  Hampton, Cody Scot, Dave Cortesi, Helder Eijs, Innokenty Lebedev,
  Joshua Klein, Matthew Clapp, Misha Turnbull, ethframe, Amir
  Ramezani, Arthur Silva, Blue, Craig MacEachern, Cédric RICARD,
  Fredrik Ahlberg, Glenn Ramsey, Jack Mordaunt, Johann Bauer, Joseph
  Heck, Kyle Stewart, Lev Maximov, Luo Shawn, Marco Nenciarini, Mario
  Costa, Matt Reynolds, Matthieu Gautier, Michael Herrmann, Moritz
  Kassner, Natanael Arndt, Nejc Habjan, Paweł Kowalik, Pedro de
  Medeiros, Peter Conerly, Peter Würtz, Rémy Roy, Saurabh Yadav, Siva
  Prasad, Steve Peak, Steven M. Vascellaro, Steven M. Vascellaro,
  Suzumizaki-Kimitaka, ThomasV, Timothée Lecomte, Torsten Sommer,
  Weliton Freitas, Zhen Zhang, dimitriepirghie, lneuhaus, s3goat,
  satarsa,


Contributions to PyInstaller 3.3.1
----------------------------------

* Hartmut Goebel - Core developer and release manager.
* Bryan A. Jones - Core developer.
* David Vierra - Core developer and encoding specialist.
* xoviat - brave contributor

* Dave Cortesi, David Hoese, John Daytona, Nejc Habjan, Addison Elliott,
  Bharath Upadhya, Bill Dengler, Chris Norman, Miles Erickson, Nick Dimou,
  Thomas Waldmann, David Weil, Placinta


Contributions to PyInstaller 3.3
----------------------------------

Special Thanks xiovat for implementing Python3.6 support and to Jonathan
Springer and xoviat for stabilizing the continuous integration tests.

* Hartmut Goebel - Core developer and release manager.
* Bryan A. Jones - Core developer.
* David Vierra - Core developer and encoding specialist.
* xoviat - brave programmer
* Jonathan Springer
* Vito Kortbeek
* Dustin Spicuzza

* Ben Hagen
* Paavo
* Brian Teague
* Chris Norman
* Jonathan Stewmon
* Guillaume Thiolliere
* Justin Harris
* Kenneth Zhao
* Paul Müller
* giumas
* y2kbugger
* 肖寅东

* Adam Clark, AndCycle, Andreas Schiefer, Arthur Silva, Aswa Paul, Bharath
  Upadhya, Brian Teague, Charles Duffy, Chris Coutinho, Cody Scott, Czarek
  Tomczak, Dang Mai, Daniel Hyams, David Hoese, Eelco van Vliet, Eric
  Drechsel, Erik Bjäreholt, Hatem AlSum, Henry Senyondo, Jan Čapek, Jeremy T.
  Hetzel, Jonathan Dan, Julie Marchant, Luke Lee, Marc Abramowitz, Matt
  Wilkie, Matthew Einhorn, Michael Herrmann, Niklas Rosenstein, Philippe
  Ombredanne, Piotr Radkowski, Ronald Oussoren, Ruslan Kuprieiev, Segev Finer,
  Shengjing Zhu 朱晟菁, Steve, Steven Noonan, Tibor Csonka, Till Bey, Tobias
  Gruetzmacher, 陳鵬宇 (float)


Contributions to PyInstaller 3.2.1
----------------------------------

Special Thanks to Thomas Waldmann and David Vierra for support when working on
the new build system.

- Hartmut Goebel - Core developer and release manager.
- Martin Zibricky - Core developer.
- David Cortesi - Core developer and documentation manager.
- Bryan A. Jones - Core developer.
- David Vierra - Core developer and encoding specialist.
- Cecil Curry - brave bug-fixing and code-refactoring

- Amane Suzuki
- Andy Cycle
- Axel Huebl
- Bruno Oliveira
- Dan Auerbach
- Daniel Hyams
- Denis Akhiyarov
- Dror Asaf
- Dustin Spicuzza
- Emanuele Bertoldi
- Glenn Ramsey
- Hugh Dowling
- Jesse Suen
- Jonathan Dan
- Jonathan Springer
- Jonathan Stewmon
- Julie Marchant
- Kenneth Zhao
- Linus Groh
- Mansour Moufid
- Martin Zibricky
- Matteo Bertini
- Nicolas Dickreuter
- Peter Würtz
- Ronald Oussoren
- Santiago Reig
- Sean Fisk
- Sergei Litvinchuk
- Stephen Rauch
- Thomas Waldmann
- Till Bald
- xoviat



Contributions to PyInstaller 3.2
----------------------------------

- Hartmut Goebel - Core developer and release manager.
- Martin Zibricky - Core developer.
- David Cortesi - Core developer and documentation manager.
- Bryan A. Jones - Core developer.
- David Vierra - Core developer and encoding specialist.
- Cecil Curry - brave bug-fixing and code-refactoring

- And Cycle - unicode fixes.
- Chris Hager - QtQuick hook.
- David Schoorisse - wrong icon paramter in Windows example.
- Florian Bruhin - typo hunting.
- Garth Bushell - Support for objcopy.
- Insoleet - lib2to3 hook
- Jonathan Springer - hook fixes, brave works on PyQt.
- Matteo Bertini - code refactoring.
- Jonathan Stewmon - bug hunting.
- Kenneth Zhao - waf update.
- Leonid Rozenberg - typo hunting.
- Merlijn Wajer -  bug fixing.
- Nicholas Chammas - cleanups.
- nih - hook fixes.
- Olli-Pekka Heinisuo -  CherryPy hook.
- Rui Carmo - cygwin fixes.
- Stephen Rauch - hooks and fixes for unnecessary rebuilds.
- Tim Stumbaugh - bug hunting.


Contributions to PyInstaller 3.1.1
----------------------------------

- Hartmut Goebel - Core developer and release manager.
- David Vierra - Core developer and encoding specialist.
- Torsten Landschoff - Fix problems with setuptools
- Peter Inglesby - resolve symlinks in modulegraph.py
- syradium - bug hunting
- dessant - bug hunting
- Joker Qyou - bug hunting


Contributions to PyInstaller 3.1
--------------------------------

- Hartmut Goebel - Core developer and release manager.
- Martin Zibricky - Core developer.
- David Cortesi - Core developer and documentation manager.
- Bryan A. Jones - Core developer.
- David Vierra - Core developer and encoding specialist.

- Andrei Kopats - Windows fixes.
- Andrey Malkov - Django runtime hooks.
- Ben Hagen - kivy hook, GStreamer realtime hook.
- Cecil Curry - Module Version Comparisons and and reworking hooks.
- Dustin Spicuzza - Hooks for GLib, GIntrospection, Gstreamer, etc.
- giumas - lxml.isoschematron hook.
- Jonathan Stewmon - Hooks for botocore, boto, boto3 and gevent.monkey.
- Kenneth Zhao - Solaris fixes.
- Matthew Einhorn - kivy hook.
- mementum - pubsub.core hook.
- Nicholas Chammas - Documentation updates.
- Nico Galoppo - Hooks for skimage and sklearn.
- Panagiotis H.M. Issaris - weasyprint hook.
- Penaz - shelve hook.
- Roman Yurchak - scipy.linalg hook.
- Starwarsfan2099 - Distorm3 hook.
- Thomas Waldmann - Fixes for Bootloader and FreeBSD.
- Tim Stumbaugh - Bug fixes.
- zpin - Bug fixes.


Contributions to PyInstaller 3.0
--------------------------------

- Martin Zibricky - Core developer and release manager.
- Hartmut Goebel - Core developer.
- David Cortesi - Initial work on Python 3 support, Python 3 fixes, documentation updates, various hook fixes.
- Cecil Curry - 'six' hook for Python 3, various modulegraph improvements, wxPython hook fixes,
- David Vierra - unicode support in bootloader, Windows SxS Assembly Manifest fixes and many other Windows improvements.
- Michael Mulley - keyring, PyNaCl import hook.
- Rainer Dreyer - OS X fixes, hook fixes.
- Bryan A. Jones - test suite fixes, various hook fixes.
- Philippe Pepiot - Linux fixes.
- Emanuele Bertoldi - pycountry import hook, Django import hook fixes.
- Glenn Ramsey - PyQt5 import hook - support for QtWebEngine on OSX, various hook fixes, Windows fixes.
- Karol Woźniak - import hook fixes.
- Jonathan Springer - PyGObject hooks. ctypes, PyEnchant hook fixes, OS X fixes.
- Giuseppe Masetti -  osgeo, mpl_toolkits.basemap and netCDF4 import hooks.
- Yuu Yamashita - OS X fixes.
- Thomas Waldmann - FreeBSD fixes.
- Boris Savelev - FreeBSD and Solaris fixes.
- Guillermo Gutiérrez - Python 3 fixes.
- Jasper Geurtz - gui fixes, hook fixes.
- Holger Pandel - Windows fixes.
- Anthony Zhang - SpeechRecognition import hook.
- Andrei Fokau - Python 3.5 fixes.
- Kenneth Zhao - AIX fixes.
- Maik Riechert - lensfunpy, rawpy import hooks.
- Tim Stumbaugh - hook fixes.
- Andrew Leech - Windows fixes.
- Patrick Robertson - tkinter import hook fixes.
- Yaron de Leeuw - import hook fixes.
- Bryan Cort - PsychoPy import hook.
- Phoebus Veiz - bootloader fixes.
- Sean Johnston - version fix.
- Kevin Zhang - PyExcelerate import hook.
- Paulo Matias - unicode fixes.
- Lorenzo Villani - crypto feature, various fixes.
- Janusz Skonieczny - hook fixes.
- Martin Gamwell Dawids - Solaris fixes.
- Volodymyr Vitvitskyi - typo fixes.
- Thomas Kho - django import hook fixes.
- Konstantinos Koukopoulos - FreeBSD support.
- Jonathan Beezley - PyQt5 import hook fixes.
- Andraz Vrhovec - various fixes.
- Noah Treuhaft - OpenCV import hook.
- Michael Hipp - reportlab import hook.
- Michael Sverdlik - certifi, httplib2, requests, jsonschema import hooks.
- Santiago Reig - appy import hook.


Contributions to PyInstaller 2.1 and older
------------------------------------------

- Glenn Ramsey - PyQt5 import hook.
- David Cortesi - PyInstaller manual rewrite.
- Vaclav Smilauer - IPython import hook.
- Shane Hansen - Linux arm support.
- Bryan A. Jones - docutils, jinja2, sphinx, pytz, idlelib import hooks.
- Patrick Stewart <patstew at gmail dot com> - scipy import hook.
- Georg Schoelly <mail at georg-schoelly dot com> - storm ORM import hook.
- Vinay Sajip - zmq import hook.
- Martin Gamwell Dawids - AIX support.
- Hywel Richards - Solaris support.
- Brandyn White - packaged executable return code fix.
- Chien-An "Zero" Cho - PyUSB import hook.
- Daniel Hyams - h2py, wx.lib.pubsub import hooks.
- Hartmut Goebel - Python logging system for message output. Option --log-level.
- Florian Hoech - full Python 2.6 support on Windows including automatic
  handling of DLLs, CRT, manifest, etc. Read and write resources from/to Win32
  PE files.
- Martin Zibricky - rewrite the build system for the bootloader using waf.
  LSB compliant precompiled bootloaders for Linux. Windows 64-bit support.
- Peter Burgers - matplotlib import hook.
- Nathan Weston - Python architecture detection on OS X.
- Isaac Wagner - various OS X fixes.
- Matteo Bertini - OS X support.
- Daniele Zannotti - OS X support.
- David Mugnai - Linux support improvements.
- Arve Knudsen - absolute imports in Python 2.5+
- Pascal Veret - PyQt4 import hook with Qt4 plugins.
- Don Dwiggins - pyodbc import hook.
- Allan Green - refactoring and improved in-process COM servers.
- Daniele Varrazzo - various bootloader and OS X fixes.
- Greg Copeland - sqlalchemy import hook.
- Seth Remington - PyGTK hook improvements.
- Marco Bonifazi - PyGTK hook improvements. PyOpenGL import hook.
- Jamie Kirkpatrick - paste import hook.
- Lorenzo Mancini - PyXML import hook fixes under Windows. OS X support. App
  bundle creation on OS X. Tkinter on OS X. Precompiled bootloaders for OS X.
- Lorenzo Berni - django import hook.
- Louai Al-Khanji - fixes with optparse module.
- Thomas Heller - set custom icon of Windows exe files.
- Eugene Prigorodov <eprigorodov at naumen dot ru> - KInterasDB import hook.
- David C. Morrill - vtkpython import hook.
- Alan James Salmoni - Tkinter interface to PyInstaller.

.. Emacs config:
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
